#include <stdlib.h>
#include <stdio.h>
#include <sane/sanei_pa4s2.h>
#include <sane/sane.h>

int
main ()
{

  int fd;
  SANE_Status status;
  u_char ccd, asic;
  u_int opt = SANEI_PA4S2_OPT_DEFAULT;

  printf ("setting options to OPT_DEFAULT...");

  status = sanei_pa4s2_options (&opt, SANE_TRUE);

  if (status != SANE_STATUS_GOOD)
    {

      printf ("failed, status %s\n", sane_strstatus (status));
      return 1;

    }

  printf ("done\nopen device 0x378...");

  status = sanei_pa4s2_open ("0x378", &fd);

  if (status != SANE_STATUS_GOOD)
    {

      printf ("failed, status %s\n", sane_strstatus (status));
      return 1;

    }

  printf ("done, device %d\nenabling device...", fd);

  status = sanei_pa4s2_enable (fd, SANE_TRUE);

  if (status != SANE_STATUS_GOOD)
    {

      printf ("failed, status %s\n", sane_strstatus (status));

      sanei_pa4s2_close (fd);

      return 1;

    }

  printf ("done\nselecting register 0 (ASIC-ID)...");

  status = sanei_pa4s2_readbegin (fd, 0);

  if (status != SANE_STATUS_GOOD)
    {

      printf ("failed, status %s\n", sane_strstatus (status));

      sanei_pa4s2_close (fd);

      return 1;

    }

  printf ("done\nreading value...");

  status = sanei_pa4s2_readbyte (fd, &asic);

  if (status != SANE_STATUS_GOOD)
    {

      printf ("failed, status %s\n", sane_strstatus (status));

      sanei_pa4s2_close (fd);

      return 1;

    }

  printf ("done, ASIC-ID ");

  switch (asic)
    {

    case 0xA8:

      printf ("1013");
      break;

    case 0xA5:

      printf ("1015");
      break;

    case 0xA2:

      printf ("1505");
      break;

    default:

      printf ("0x%02x - unkown ID", asic);
      break;

    }

  printf ("\nresetting register...");

  status = sanei_pa4s2_readend (fd);

  if (status != SANE_STATUS_GOOD)
    {

      printf ("failed, status %s\n", sane_strstatus (status));

      sanei_pa4s2_close (fd);

      return 1;

    }

  printf ("done\nselecting register 2 (CCD-Info)...");

  status = sanei_pa4s2_readbegin (fd, 2);

  if (status != SANE_STATUS_GOOD)
    {

      printf ("failed, status %s\n", sane_strstatus (status));

      sanei_pa4s2_close (fd);

      return 1;

    }

  printf ("done\nreading value...");

  status = sanei_pa4s2_readbyte (fd, &ccd);

  if (status != SANE_STATUS_GOOD)
    {

      printf ("failed, status %s\n", sane_strstatus (status));

      sanei_pa4s2_close (fd);

      return 1;

    }

  printf ("done, CCD-Type ");

  switch (asic)
    {

    case 0xA8:

      printf ("%02u", ccd & 0x04);
      break;

    case 0xA5:

      printf ("%02u", ccd & 0x05);
      break;

    default:

      printf ("0x%02x", ccd);
      break;

    }

  printf ("\nresetting register...");

  status = sanei_pa4s2_readend (fd);

  if (status != SANE_STATUS_GOOD)
    {

      printf ("failed, status %s\n", sane_strstatus (status));

      sanei_pa4s2_close (fd);

      return 1;

    }

  printf ("done\nclosing device...");

  sanei_pa4s2_close (fd);

  puts ("done.");

  return 0;
}
